



if not exist %PREFIX%\\Library\\bin\\opencv_aruco331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_bgsegm331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_calib3d331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_ccalib331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_core331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_datasets331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_dnn331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_dpm331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_face331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_features2d331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_flann331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_fuzzy331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_highgui331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_imgcodecs331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_imgproc331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_line_descriptor331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_ml331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_objdetect331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_optflow331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_phase_unwrapping331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_photo331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_plot331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_reg331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_rgbd331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_saliency331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_shape331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_stereo331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_stitching331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_structured_light331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_superres331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_surface_matching331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_text331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_tracking331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_video331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_videoio331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_videostab331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_xfeatures2d331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_ximgproc331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_xobjdetect331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %PREFIX%\\Library\\bin\\opencv_xphoto331.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
